# remirepo spec file for php-pecl-teds
#
# Copyright (c) 2021-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-teds}

%bcond_without      tests

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   teds
%global ini_name    40-%{pecl_name}.ini

%global upstream_version 1.3.0
#global upstream_prever  a1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        Tentative Extra Data Structures
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}

License:        BSD-3-Clause
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

Patch0:         %{pecl_name}-php83.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
teds (Tentative Extra Data Structures) is a collection of data structures
and iterable functionality.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/COPYING/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b.pr204

# Check version as upstream often forget to update this
extver=$(sed -n '/define PHP_TEDS_VERSION/{s/.* "//;s/".*$//;p}' php_teds.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}%{?gh_date:-dev}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

peclconf() {
%configure \
    --enable-teds \
    --with-php-config=$1
}

cd %{sources}
%{__phpize}

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do [ -f %{sources}/$i ] &&  install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%endif

%if %{with tests}
cd %{sources}
: Run upstream test suite
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff %{?_smp_mflags}
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/COPYING}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 1.3.0-2
- build out of sources tree
- add patch for test suite with PHP 8.3 from
  https://github.com/TysonAndre/pecl-teds/pull/204

* Thu Nov 10 2022 Remi Collet <remi@remirepo.net> - 1.3.0-1
- update to 1.3.0

* Thu Oct 27 2022 Remi Collet <remi@remirepo.net> - 1.2.8-1
- update to 1.2.8 (no change)

* Mon Oct 24 2022 Remi Collet <remi@remirepo.net> - 1.2.7-1
- update to 1.2.7

* Tue Oct 11 2022 Remi Collet <remi@remirepo.net> - 1.2.6-1
- update to 1.2.6

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 1.2.4-2
- rebuild for PHP 8.2.0RC1

* Tue Aug 16 2022 Remi Collet <remi@remirepo.net> - 1.2.4-1
- update to 1.2.4

* Mon Mar  7 2022 Remi Collet <remi@remirepo.net> - 1.2.3-1
- update to 1.2.3

* Fri Mar  4 2022 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Mon Feb 21 2022 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Thu Feb 17 2022 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Mon Feb 14 2022 Remi Collet <remi@remirepo.net> - 0.14.0-1
- update to 0.14.0

* Thu Feb 10 2022 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0

* Wed Feb  9 2022 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0

* Mon Feb  7 2022 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0

* Mon Jan 31 2022 Remi Collet <remi@remirepo.net> - 0.9.2-1
- update to 0.9.2

* Thu Jan 27 2022 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0

* Mon Jan 24 2022 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0

* Tue Jan 18 2022 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0

* Mon Jan 17 2022 Remi Collet <remi@remirepo.net> - 0.5.1-1
- update to 0.5.1

* Mon Sep 27 2021 Remi Collet <remi@remirepo.net> - 0.4.1-1
- update to 0.4.1

* Mon Sep 20 2021 Remi Collet <remi@remirepo.net> - 0.3.0-1
- update to 0.3.0

* Sat Sep 18 2021 Remi Collet <remi@remirepo.net> - 0.2.1-1
- update to 0.2.1

* Mon Sep 13 2021 Remi Collet <remi@remirepo.net> - 0.2.0-1
- update to 0.2.0

* Sat Sep 11 2021 Remi Collet <remi@remirepo.net> - 0.1.1-1
- update to 0.1.1 (stable)

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 0.1.0~a1-2
- rebuild for 8.1.0RC1

* Wed Aug 25 2021 Remi Collet <remi@remirepo.net> - 0.1.0~a1-1
- initial package
